﻿using System;
using System.Collections.ObjectModel;
using System.Windows;
using Infragistics;
using Infragistics.Controls.Charts;

namespace RealTimeStackedAreaSeriesChart
{
    using System.ComponentModel;
    using System.Windows.Threading;

    public partial class MainWindow : Window
    {
        public ObservableCollection<CategoryData> RetVal { get; set; }

        private DispatcherTimer timer;

        public MainWindow()
        {
            InitializeComponent();
            RetVal = new ObservableCollection<CategoryData>();

            this.timer = new DispatcherTimer();
            this.timer.Interval = TimeSpan.FromMilliseconds(1000);
            this.timer.Tick += this.OnTimer;
        }

        private void OnTimer(object sender, EventArgs e)
        {
            SimulateData();
        }

        private void SimulateData()
        {
            int stIdx = new Random().Next(1, 4);

            ObservableCollection<CategoryData> newCollection = theChart.Series[0].ItemsSource as ObservableCollection<CategoryData>;
            newCollection[stIdx].Value = new Random().Next(60, 1300);
        }

        private void MainWindow_OnLoaded(object sender, RoutedEventArgs e)
        {
            RetVal = StationDataCollection.GetItemSource();
            Infragistics.Controls.Charts.NumericYAxis yAxis = new NumericYAxis();

            CategoryXAxis xAxis = new CategoryXAxis();
            xAxis.ItemsSource = RetVal;
            xAxis.Label = "{Category}";
            this.theChart.Axes.Add(xAxis);
            this.theChart.Axes.Add(yAxis);

            StackedColumnSeries series = new StackedColumnSeries();
        
            series.XAxis = xAxis;
            series.YAxis = yAxis;
            series.ItemsSource = RetVal;

            series.Series.Add(new StackedFragmentSeries
            {
                ValueMemberPath = "Value"
            });

            series.Series.Add(new StackedFragmentSeries
            {
                ValueMemberPath = "Value1"
            });

            theChart.Series.Add(series);
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
             this.timer.Start();
        }

        private void Button2_Click(object sender, RoutedEventArgs e)
        {
             this.timer.Stop();
        }
    }

    public class StationDataCollection
    {
        public static ObservableCollection<CategoryData> GetItemSource()
        {
            DateTime dt = DateTime.Now;
            ObservableCollection<CategoryData> retVal = new ObservableCollection<CategoryData>();
             
            retVal.Add(new CategoryData("Series 2", 1100, "Category 1"));
             
            retVal.Add(new CategoryData("Series 2", 1400, "Category 2"));
             
            retVal.Add(new CategoryData("Series 2", 800, "Category 3"));
             
            retVal.Add(new CategoryData("Series 2", 200, "Category 4"));
            
            return retVal;
        }
    }

    public class CategoryData : INotifyPropertyChanged
    {
        private double value;
        private double value1;

        public string Category { get; set; }

        public string SeriesName { get; set; }

        public double Value 
        {
            get
            {
                return this.value;
            }
            set
            {
                this.value = value;
                OnPropertyChanged("Value");
            }
        }
        public double Value1
        {
            get
            {
                return this.value1;
            }
            set
            {
                this.value1 = value;
                OnPropertyChanged("Value1");
            }
        }
        public CategoryData(string seriesName, double value, string category)
        {
            SeriesName = seriesName;
            Value = value;
            Value1 = value + 10;
            Category = category;
        }

        #region INotifyPropertyChanged
        public event PropertyChangedEventHandler PropertyChanged;
        public void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
        #endregion
    }
}